@@ -36,6 +36,11 @@ int main(int argc, char* argv[])
 
 	EicielContainer w;
 
+	if (argc > 1)
+	{
+		w.obrirFitxer(argv[1]);
+	}
+
 	kit.run(w);
 
 	return 0;
